# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import enum

import winrt.system
from winui3._winui3_microsoft_windows_widgets_notifications import (
    FeedAnnouncement,
    FeedAnnouncementInvokedArgs,
)

__all__ = [
    "AnnouncementActionKind",
    "AnnouncementTextColor",
    "FeedAnnouncement",
    "FeedAnnouncementInvokedArgs",
]

class AnnouncementActionKind(enum.IntEnum):
    SHOWN = 0
    ENGAGED = 1

class AnnouncementTextColor(enum.IntEnum):
    DEFAULT = 0
    DARK = 1
    LIGHT = 2
    ACCENT = 3
    GOOD = 4
    WARNING = 5
    ATTENTION = 6

